Module practice

Module practice 

Practice specification types: PracticeSpec, TurnPolicy, and DurationPolicy.

Structs

PracticeSpec
Full specification for a practice, deserialized from a TOML definition file.

Enums

DurationPolicy
Controls how long a practice runs.
TurnPolicy
Controls whose turn it is at each beat of a practice.